capture log close
log using wflec-dual-data04-lhsbinary, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: dual workflow - data 04 create binary indicators

local pgm wflec-dual-data04-lhsbinary
local dte 2017-06-16
local who Scott Long
local tag `pgm'.do `who' `dte'

//  #1 setup

local srcdata wflec-dual-data02
local savdata wflec-dual-data03

use `srcdata', clear
datasignature confirm

//  #2 check source variables for indicators of support

* names are easier to work with
clonevar momwarm5   = v4
clonevar kidsuffer5 = v5
clonevar famsuffer5 = v6
clonevar wantboth5  = v7
clonevar housesat5  = v8
clonevar workindep5  = v9

local srcnms "momwarm5 kidsuffer5 famsuffer5 wantboth5 housesat5 workindep5"
codebook `srcnms', compact
tab1 `srcnms', miss
pwcorr `srcnms', obs // check direction of coding

//  #3 create BH binary high support vs not

label def LBHprowork 1 StrProWrk  0 Not .a a_Unsure .b b_Refused .n n_Neutral

* momwarm5: 1=strong pro work => BHwarm
recode momwarm5 (1=1) (2=0) (4/5=0) (3=.n) (8=.a) (9=.b), gen(BHwarm)
label var BHwarm "Working mom can have warm relations"
label val BHwarm LBHprowork
note BHwarm: strong pro from momwarm 3=neutral coded .n \ `tag'
tab momwarm5 BHwarm, miss

* kidsuffer5: 5=strong pro work => BHkidsuf
recode kidsuffer5 (1/2 4=0) (5=1) (3=.n) (8=.a) (9=.b), gen(BHkidsuf)
label var BHkidsuf "Kids don't suffer with working mom"
label val BHkidsuf LBHprowork
note BHkidsuf: strong pro from kidsuffer5 3=neutral coded .n \ `tag'
tab kidsuffer5 BHkidsuf, miss

* famsuffer5: 5=strong pro work => BHfamsuf
recode famsuffer5 (1/2 4=0) (5=1) (3=.n) (8=.a) (9=.b), gen(BHfamsuf)
label var BHfamsuf "Family life doesn't suffer"
label val BHfamsuf LBHprowork
note BHfamsuf: strong pro from famsuffer5 3=neutral coded .n \ `tag'
tab famsuffer5 BHfamsuf, miss

* wantboth5: 1=strong pro work => BHnotboth
recode wantboth5 (1/2 4=0) (5=1) (3=.n) (8=.a) (9=.b), gen(BHnotboth)
label var BHnotboth "Women don't want home and kids"
label val BHnotboth LBHprowork
note BHnotboth: strong pro from wantboth5 3=neutral coded .n \ `tag'
tab wantboth5 BHnotboth, miss

* housesat5: 1=strong pro work => BHjobsat
recode housesat5 (1/2 4=0) (5=1) (3=.n) (8=.a) (9=.b), gen(BHjobsat)
label var BHjobsat "Agree paid job satisfies more?"
label val BHjobsat LBHprowork
note BHjobsat: strong pro from housesat5 3=neutral coded .n \ `tag'
tab housesat BHjobsat, miss

* workindep5: 1=strong pro work => BHindep
recode workindep5 (1=1) (2 4/5=0) (3=.n) (8=.a) (9=.b), gen(BHindep)
label var BHindep "Work best for mom's independence"
label val BHindep LBHprowork
note BHindep: strong pro from workindep5 3=neutral coded .n \ `tag'
tab workindep5 BHindep, miss

//  check that all are coded in same direction

codebook BH*, compact
pwcorr BH*, obs

//  #4 include neutral as not strong support

label def LBNprowork 1 StrProWrk  0 NotNeut .a a_Unsure .b b_Refused

* momwarm5: 1=strong pro work => BNwarm
recode momwarm5 (1=1) (2/5=0) (8=.a) (9=.b), gen(BNwarm)
label var BNwarm "Working mom can have warm relations"
label val BNwarm LBNprowork
note BNwarm: strong pro from momwarm 3=neutral coded not \ `tag'
tab momwarm5 BNwarm, miss

* kidsuffer5: 5=strong pro work => BNkidsuf
recode kidsuffer5 (1/4=0) (5=1) (8=.a) (9=.b), gen(BNkidsuf)
label var BNkidsuf "Kids don't suffer with working mom"
label val BNkidsuf LBNprowork
note BNkidsuf: strong pro from kidsuffer5 3=neutral coded not \ `tag'
tab kidsuffer5 BNkidsuf, miss

* famsuffer5: 5=strong pro work => BNfamsuf
recode famsuffer5 (1/4=0) (5=1) (8=.a) (9=.b), gen(BNfamsuf)
label var BNfamsuf "Family life doesn't suffer"
label val BNfamsuf LBNprowork
note BNfamsuf: strong pro from famsuffer5 3=neutral coded not \ `tag'
tab famsuffer5 BNfamsuf, miss

* wantboth5: 1=strong pro work => BNnotboth
recode wantboth5 (1/4=0) (5=1) (8=.a) (9=.b), gen(BNnotboth)
label var BNnotboth "Women don't want home and kids"
label val BNnotboth LBNprowork
note BNnotboth: strong pro from wantboth5 3=neutral coded not \ `tag'
tab wantboth5 BNnotboth, miss

* housesat5: 1=strong pro work => BNjobsat
recode housesat5 (1/2 4=0) (5=1) (3=.n) (8=.a) (9=.b), gen(BNjobsat)
label var BNjobsat "Agree paid job satisfies more?"
label val BNjobsat LBNprowork
note BNjobsat: strong pro from housesat5 3=neutral coded not \ `tag'
tab housesat BNjobsat, miss

* workindep5: 1=strong pro work => BNindep
recode workindep5 (1=1) (2/5=0) (8=.a) (9=.b), gen(BNindep)
label var BNindep "Work best for mom's independence"
label val BNindep LBNprowork
note BNindep: strong pro from workindep5 3=neutral coded not \ `tag'
tab workindep5 BNindep, miss

//  check that all are coded in same direction

codebook BN*, compact
pwcorr BN*, obs

//  #5 save dataset

codebook female-BNindep, compact // analysis variables
notes female-BNindep

label data "`savdata'.dta | ISSP Russia 2002 Working Women | `dte'"
notes: `savdata'.dta | `tag' | add binary outcome indicators
datasignature set, reset
save `savdata', replace
notes _dta

//  #6 check the new dataset

use `savdata', clear
datasignature confirm

* changes from soruce dataset
capture noisily cf _all using `srcdata'.dta, all

log close //
exit


* new value labels
label def Lagree 1 Agree  0 No .a a_Unsure .b b_Refused .n n_Neutral
