capture log close
log using wfauto-05loops, replace text
version 13.1
clear all
set linesize 80
macro drop _all
set scheme s2manual

//  Guide to Automating Your Work in Stata
//  Scott Long & Bianca Manago
//  loops

local pgm wfauto-05loops
local dte 2015-05-15
local who scott long
local tag "`pgm' `who' `dte'"

//  load data

use wf-lfp, clear
notes

//  #1 foreach loop using display and summarize

local varlist "lfp k5 k618 wc hc"

* foreach loop using display
foreach varnm in `varlist' {
    display "`varnm'"
}

* foreach loop using summarize
foreach varnm in `varlist' {
    summarize `varnm'
}

//  #2 foreach loop creating rows of summary statistics

* locals used by display
local C1 = 5    // table column 1 begins at 5
local C2 = 20   // table column 2 begins at 20
local C3 = 30   // table column 3 begins at 30
local W2 = 10   // table column 1 has width 10
local W3 = 10   // table column 3 has width 10
local D2 = 2    // table column 2 has 2 decimal places
local D3 = 3    // table column 3 has 3 decimal places

* loop through the variables
foreach varnm in `varlist' {
    quietly summarize `varnm' // compute statistics
    local mn = r(mean) // grab returns
    local sd = r(sd)
    di  _col(`C1') "`varnm'" ///
        _col(`C2') "Mean = " %-`W2'.`D2'f  `mn' ///
        _col(`C3') "SD = "   %-`W3'.`D3'f  `sd'
}

* add min and max
local C1 = 1
local C2 = 10
local C3 = 18
local C4 = 26
local C5 = 34
local C6 = 42
local W = 8 // same width for all columns

di  _col(`C1') "Variable" _col(`C2') "Mean"  _col(`C3') "SD " ///
    _col(`C4') "Min"      _col(`C5') "Max"   _col(`C6') "Label"

foreach varnm in `varlist' {
    quietly summarize `varnm'
    local mn = r(mean)
    local sd = r(sd)
    local min = r(min)
    local max = r(max)
    local varlbl : variable label `varnm'
    di  _col(`C1') "`varnm'" ///
        _col(`C2') %-`W'.`D3'f  `mn'  _col(`C3') %-`W'.`D3'f  `sd'  ///
        _col(`C4') %-`W'.`D3'f  `min' _col(`C5') %-`W'.`D3'f  `max' ///
        _col(`C6') "`varlbl'"
}

log close
exit
