capture log close
log using wfauto-06table, replace text
version 13.1
clear all
set linesize 80
macro drop _all
set scheme s2manual

//  Guide to Automating Your Work in Stata
//  Scott Long & Bianca Manago
//  enhanced table

local pgm wfauto-06table
local dte 2015-05-15
local who scott long
local tag "`pgm' `who' `dte'"

//  load data

use wf-lfp, clear
notes

//  #1 List of variables to be included

local varset "lfp k5 k618 age wc hc lwg inc"
di "`varset'"

// #2 Locals for formatting preferences

// This will be the basic format of the table. It is here so that we can see
// everything that we will need to create a local for
//
//    di _col(`Cvar') "`varnm'"  ///
//       _col(`Cmn') %-`Wmn'.`Dmn'f `mean' ///
//       _col(`Csd')  %-`Wsd'.`Dsd'f `stdv' ///
//       _col(`Cmin') %-`Wmin'.`Dmin'f `min' ///
//       _col(`Cmax') %-`Wmax'.`Dmax'f `max' ///
//       _col(`Clbl') "`varlblshort'"

* C == column where each statistics will start
local Cvar  = 1
local Cmn   = 8
local Csd   = 17
local Cmin  = 26
local Cmax  = 35
local Clbl  = 45

* W == width
local Wmn   = 8
local Wsd   = 8
local Wmin  = 8
local Wmax  = 8

* D == decimal digits
local Dmn   = 3
local Dsd   = 3
local Dmin  = 3
local Dmax  = 3

* L == labels for statistics (spaces help center names)
local Lvar "Name"
local Lmn  "    Mean"
local Lsd  "      SD"
local Lmin "     Min"
local Lmax "     Max"
local Llbl "Description"

* Length of var label to be displayed
local VLlen = 32

// #3 Using a loop, calculate statistics

local listheader yes // at first we want to list a header

foreach varnm in `varset' {
    if "`listheader'"=="yes" {
        di _col(`Cvar') "`Lvar'" _col(`Cmn')  "`Lmn'"  _col(`Csd')  "`Lsd'" ///
           _col(`Cmin') "`Lmin'" _col(`Cmax') "`Lmax'" _col(`Clbl') "`Llbl'"
       local listheader "no" // we no longer need to list the header
    }
    qui sum `varnm'
    * place returns into locals
    local mean = r(mean)
    local stdv = r(sd)
    local min= r(min)
    local max= r(max)
    * retrieve variable label
    local varlbl : variable label `varnm'
    local varlblshort = abbrev("`varlbl'",`VLlen') // abbreviate label
    * display statistics with formatting
    di _col(`Cvar') "`varnm'"  ///
	   _col(`Cmn')  %`Wmn'.`Dmn'f `mean' ///
	   _col(`Csd')  %`Wsd'.`Dsd'f `stdv' ///
	   _col(`Cmin') %`Wmin'.`Dmin'f `min' ///
	   _col(`Cmax') %`Wmax'.`Dmax'f `max' ///
	   _col(`Clbl') "`varlblshort'"
}

log close
exit
