capture log close
log using wfauto-07matrixexcel, replace text
version 13.1
clear all
set linesize 80
macro drop _all
set scheme s2manual

//  Guide to Automating Your Work in Stata
//  Scott Long & Bianca Manago
//  matrices and putexcel

local pgm wfauto-07matrixexcel
local dte 2015-05-15
local who scott long
local tag "`pgm' `who' `dte'"

//  load data

use wf-lfp, clear
notes

//  #1 Planning names and labels

* header for spreadsheet
putexcel B1 = ("Dataset: wf-lfp.dta") using `pgm'-varplan.xlsx, replace
putexcel B2 = ("Author: `who'") using `pgm'-varplan.xlsx, modify
putexcel B3 = ("Date: `dte'") using `pgm'-varplan.xlsx, modify
putexcel B4 = ("Pgm: `pgm'.do") using `pgm'-varplan.xlsx, modify

* names of variables
unab varnms : _all // get the unabbreviated names
display "`varnms'"

* save names and label to excel

local irow = 6 // start names in this row
foreach varnm in `varnms' {
    local varlbl : variable label `varnm'
    putexcel B`irow' = ("`varnm'") /// place in col B, row irow
             C`irow' = (`"`varlbl'"') /// place in col C, row irow
             using `pgm'-varplan.xlsx, modify
    local ++irow // increment the irow by 1
}

//  #2 A spreadsheet with descriptive statistics

* header
putexcel B1 = ("Dataset: wf-lfp.dta") using `pgm'-descstats.xlsx, replace
putexcel B2 = ("Author: `who'") using `pgm'-descstats.xlsx, modify
putexcel B3 = ("Date: `dte'") using `pgm'-descstats.xlsx, modify
putexcel B4 = ("Pgm: `pgm'.do") using `pgm'-descstats.xlsx, modify

* which variables
unab varnms : _all
local varnmsN = wordcount("`varnms'") // # of variables

* which statistics in which columns
local statnms "Mean SD Min Max"
local statnmsN = wordcount("`statnms'")
local Cmn  = 1
local Csd  = 2
local Cmin = 3
local Cmax = 4

* matrix filled with -99's
matrix stattable = J(`varnmsN',`statnmsN',-99)
matrix rownames stattable = `varnms'
matrix colnames stattable = `statnms'
matlist stattable

* calculate statistics and populate matrix
local ivar = 0
foreach varnm in `varnms' {
    local ++ivar
    qui sum `varnm'
    matrix stattable[`ivar',`Cmn']  = r(mean)
    matrix stattable[`ivar',`Csd']  = r(sd)
    matrix stattable[`ivar',`Cmin'] = r(min)
    matrix stattable[`ivar',`Cmax'] = r(max)
}
matlist stattable, format(%8.4f) title(The stattable matrix)

* put matrix into excel
local irow = 6 // column names are placed in this row
putexcel B`irow' = matrix(stattable, names) ///
    using `pgm'-descstats.xlsx, modify

* add variable labels
foreach varnm in `varnms' {
    local ++irow
    local varlbl : variable label `varnm'
    putexcel G`irow' = (`"`varlbl'"') using "`pgm'-descstats.xlsx", modify
}

log close
exit

NOTES