capture log close
log using wflec-analysis-collect-nested, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: analysis - collect results from nested regressions

local pgm wflec-analysis-collect-nested
local dte 2017-06-19
local who Scott Long
local tag "`pgm'.do `who' `dte'"

//  #1 load data and select sample

use wf-tenure, clear
datasignature confirm
keep if sampleis

//  #2 define groups of variables

local Vbase female
local Vtime year yearsq      // time in rank
local Vdept select prestige  // characteristics of departments
local Vprod articles         // research productivity

//  #3 matrix for results

capture matrix drop matnest
local rowlist Vbase Vtime Vdept Vprod
local ncols = 4
matrix vecorig = J(1,`ncols',-999)
matrix colnames vecorig = ORfem zfem pfem BICfem

foreach varset in Vbase Vtime Vdept Vprod {

    mat myvec = vecorig

    local rhs "`rhs' ``varset''"
    `qui' logit tenure `rhs'

    * get stats and compute pvalue
    local b = _b[female]
    local or = exp(`b')
    local se = _se[female]
    local z = `b'/`se'
    local pval = 2*(1-normal(abs([`z'])))

    * get bic
    qui estat ic
    scalar ic = el(r(S),1,6)

    * save results
    mat myvec[1,1] = `or'
    mat myvec[1,2] = `z'
    mat myvec[1,3] = `pval'
    mat myvec[1,4] = ic
    mat rownames myvec = `varset'
    mat matnest = nullmat(matnest) \ myvec
}

//  #4 print results

matlist matnest, format(%8.3f)

log close
exit
