capture log close
log using wflec-dual-data01-list, replace text
version 14.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: dual workflow - data 01 list variable informaton

local pgm wflec-dual-data01-list
local dte 2017-06-16
local who Scott Long
local tag `pgm'.do `who' `dte'

//  #1 setup

use rr-issp-russia01, clear
datasignature confirm

unab  varnms : _all // retrieve names of all variabes
local varnmsN = wordcount("`varnms'") // # of variables

codebook `varnms', compact

* shorten list to speed up program

local varnms "v2 v4 v5 v6 v7 v8 v9 v10 v11 v12 v13 v14 v15 v16 v17 v18 v19"
* v20 v21 v22 v23 v24 v25 v26 v27 v28 v29 v30 v31 v32 v33 v34 v35
* v36 v37 v38 v39 v40 v41 v42 v43 v44 v45 v46 v47

//  #2 create spreadsheet with source var info for planning

putexcel set `pgm'-vars.xlsx, replace

putexcel B2 = "Dataset: rr-issp-russia01.dta"
putexcel B3 = "Author: `who'"
putexcel B4 = "Date: `dte'"
putexcel B5 = "Pgm: `pgm'.do"

* column labels
local qui ""
local irow = 7 // start row in spreadsheet
`qui' putexcel B`irow' = "Original"
`qui' putexcel C`irow' = "Original"
`qui' putexcel D`irow' = "Original"

local ++irow
`qui' putexcel B`irow' = "Var Name"
`qui' putexcel C`irow' = "Var Label"
`qui' putexcel D`irow' = "Val Label"

* variable information
foreach varnm in `varnms' {

* di "irow `irow'"
    local ++irow
    local vallbl : value label `varnm'
    local varlbl : variable label `varnm'
    `qui' putexcel B`irow' = "`varnm'"
    `qui' putexcel C`irow' = "`varlbl'"
    `qui' putexcel D`irow' = "`vallbl'"
}

//  #3 text file with names and labels

capture file close myfile
file open myfile using `pgm'-vars.txt, write replace

local Cvarnm  = 9
local Cvallbl = 15
local Cvarlbl = 25

file write myfile "" _col(`Cvarnm') "Var" ///
    _col(`Cvallbl') "Value" _col(`Cvarlbl') "Var" _newline
file write myfile "Number" _col(`Cvarnm') "Name" ///
    _col(`Cvallbl') "Label" _col(`Cvarlbl') "Label" _newline

local ivar = 1
foreach varnm in `varnms' {

* di "ivar `ivar'"
    local varlbl : variable label `varnm' // get var label
    local vallbl : value label `varnm' // get val label
    file write myfile "`ivar'" _col(`Cvarnm') "`varnm'" ///
        _col(`Cvallbl') "`vallbl'" _col(`Cvarlbl') "`varlbl'" _newline
    local ++ivar
}

file close myfile

log close
exit
