capture log close
log using wflec-dual-stat04-irtbin, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: dual workflow - stat 04 IRT on binary indicators of outcome
//  High support vs not; exclude neutral

local pgm wflec-dual-stat04-irtbin
local dte 2017-06-16
local who Scott Long
local tag `pgm'.do `who' `dte'

//  #1 setup

use wflec-dual-data03, clear
datasignature confirm

local m1rhs female age married logfaminc
local m2rhs `m1rhs' highered fulltime
local m3rhs `m2rhs' momworks kidsnone
local regvars `m3rhs'

* require all rhs variables to be nonmissing
qui reg `regvars' // quick way to select listwise deletion sample
keep if e(sample)

//  #2 check variables: note missing data

local vars BHwarm BHkidsuf BHfamsuf BHnotboth BHjobsat BHindep

codebook `vars', compact
pwcorr   `vars', obs

//  #3 summated Scale

alpha `vars', gen(prowrkSS)
label var prowrkSS "Support working women: sumscale binary items"
sum prowrkSS

//  #4 IRT 1pl

eststo irt1: irt 1pl `vars', intpoints(18) nolog // 1pl IRT
predict   prowrkIR1, latent
label var prowrkIR1 "Support working women: IRT-1pl scores"

//  #5 IRT 2pl

eststo irt2: irt 2pl `vars', intpoints(18) nolog // 2pl IRT
matrix temp = r(table)
predict   prowrkIR2, latent
label var prowrkIR2 "Support working women: IRT-2pl scores"

* table with alternative parameterizations
matrix parm = temp[1,1...]
matrix pval = temp[4,1...]

mat irt2tbl = J(6,6,.)
mat rownames irt2tbl = `vars'
mat colnames irt2tbl = Discrim:Estimate Discrim:pval ///
Diff:Estimate Diff:pval Intercept:Estimate Intercpt:pval

local col = 0
local k = 0
foreach var in `vars' {
    local ++k
    local ++col
    mat irt2tbl[`k',1] = parm[1,`col'] // irt disc
    mat irt2tbl[`k',2] = pval[1,`col']
    local ++col
    mat irt2tbl[`k',3] = parm[1,`col'] // irt diff
    mat irt2tbl[`k',4] = pval[1,`col']
    mat irt2tbl[`k',5] = _b[`var':_cons] // logit constant
    qui test _b[`var':_cons] = 0
    mat irt2tbl[`k',6] = r(p)
}
matlist irt2tbl, title(IRT 2pl model parameters) format(%9.3f)

//  #6 IRT1 and IRT2:  LR Test, AIC, BIC
//  Note: select irt2

lrtest    irt1 irt2

estimates restore irt1
estat ic

estimates restore irt2
estat ic

codebook prowrk*, compact
pwcorr   prowrk*, obs

log close
exit


* put matrix in excel spreadsheet
putexcel set `pgm'-irtparm.xlsx, replace
putexcel B2 = matrix(irt2tbl, names), modify

// metadata for dataset

label data "ISSP Russia 2002 | `dte'"
notes: `savdata' | dataset includes generated IRT scales from binary outcomes ///
 in addition to variables already in rr-issp-russia03. | `tag'

// datasignature
datasignature set, reset

// save dataset

save `savdata', replace

// check the new dataset

use `savdata', clear
datasignature confirm

