capture log close
log using wflec-present-tables-esttab, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: present - creating tables

local pgm wflec-present-tables-esttab
local dte 2017-06-20
local who Scott Long
local tag "`pgm'.do `who' `dte'"

//  #1 load data and select sample

use wf-tenure, clear
datasignature confirm
keep if sampleis

//  #2 define groups of variables

local Vtime "year yearsq"       // time in rank
local Vdept "select prestige"   // characteristics of department affiliations
local Vprod "articles"          // research productivity

//  #3 nested models predicting tenure

//  #3a - baseline gender only model

logit tenure female, nolog or
eststo

//  #3b + time

logit tenure female `Vtime', nolog or
eststo

//  #3c + department

logit tenure female `Vtime' `Vdept', nolog or
eststo

//  #4 esttab options

//  #4a - default

esttab

//  #4b - near final table

esttab, eform nostar bic label varwidth(33) ///
    title("Table 7.1: Workflow Example of Jann's esttab Command.") ///
    mtitles("Model A" "Model B" "Model C") ///
    addnote("Source: wflec-present-tables-esttab.do")

//  #4c - for latex

esttab using wflec-present-tables-esttab.tex, ///
    eform nostar bic label varwidth(33) ///
    mtitles("Model A" "Model B" "Model C") ///
    addnote("Source: wflec-present-tables-esttab.do") replace

log close
exit